Module markers

Module markers 

Marker types for simulation model methods.

Structs

AsyncWithScheduler
Marker type for asynchronous simulation model methods that take a mutable reference to the model, a message and an explicit scheduler argument.
AsyncWithoutArguments
Marker type for asynchronous simulation model methods that take a mutable reference to the model, without any other argument.
AsyncWithoutScheduler
Marker type for asynchronous simulation model methods that take a mutable reference to the model and a message, without scheduler argument.
WithScheduler
Marker type for regular simulation model methods that take a mutable reference to the model, a message and an explicit scheduler argument.
WithoutArguments
Marker type for regular simulation model methods that take a mutable reference to the model, without any other argument.
WithoutScheduler
Marker type for regular simulation model methods that take a mutable reference to the model and a message, without scheduler argument.