pub enum SystemTimeError {
InvalidSystemTime,
OutOfRange,
}Expand description
An error that may be returned when initializing a MonotonicTime from
system time.
Variants
InvalidSystemTime
The system time is in the past of the Unix epoch.
OutOfRange
The system time cannot be represented as a MonotonicTime.