Marker types for simulation model methods.
Structs
- Async
With Scheduler - Marker type for asynchronous simulation model methods that take a mutable reference to the model, a message and an explicit scheduler argument.
- Async
Without Arguments - Marker type for asynchronous simulation model methods that take a mutable reference to the model, without any other argument.
- Async
Without Scheduler - Marker type for asynchronous simulation model methods that take a mutable reference to the model and a message, without scheduler argument.
- With
Scheduler - Marker type for regular simulation model methods that take a mutable reference to the model, a message and an explicit scheduler argument.
- Without
Arguments - Marker type for regular simulation model methods that take a mutable reference to the model, without any other argument.
- Without
Scheduler - Marker type for regular simulation model methods that take a mutable reference to the model and a message, without scheduler argument.